Enum SubProtocolError
enum SubProtocolError
Indicates the specific type/cause of a subprotocol header error.
Variants
-
ServerSentSubProtocolNoneRequested The server sent a subprotocol to a client handshake request but none was requested
-
InvalidSubProtocol The server sent an invalid subprotocol to a client handhshake request
-
NoSubProtocol The server sent no subprotocol to a client handshake request that requested one or more subprotocols
Implementations
impl Clone for SubProtocolError
fn clone(self: &Self) -> SubProtocolError
impl Copy for SubProtocolError
impl Debug for SubProtocolError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for SubProtocolError
fn fmt(self: &Self, __formatter: &mut Formatter<'_>) -> Result
impl Eq for SubProtocolError
impl Error for SubProtocolError
impl Freeze for SubProtocolError
impl PartialEq for SubProtocolError
fn eq(self: &Self, other: &SubProtocolError) -> bool
impl RefUnwindSafe for SubProtocolError
impl Send for SubProtocolError
impl StructuralPartialEq for SubProtocolError
impl Sync for SubProtocolError
impl Unpin for SubProtocolError
impl UnsafeUnpin for SubProtocolError
impl UnwindSafe for SubProtocolError
impl<T> Any for SubProtocolError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SubProtocolError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SubProtocolError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for SubProtocolError
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for SubProtocolError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Same for SubProtocolError
impl<T> ToOwned for SubProtocolError
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for SubProtocolError
fn to_string(self: &Self) -> String
impl<T, U> Into for SubProtocolError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SubProtocolError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SubProtocolError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<V, T> VZip for SubProtocolError
fn vzip(self: Self) -> V