Enum UrlError

enum UrlError

Indicates the specific type/cause of URL error.

Variants

TlsFeatureNotEnabled

TLS is used despite not being compiled with the TLS feature enabled.

NoHostName

The URL does not include a host name.

UnableToConnect(String)

Failed to connect with this URL.

UnsupportedUrlScheme

Unsupported URL scheme used (only ws:// or wss:// may be used).

EmptyHostName

The URL host name, though included, is empty.

NoPathOrQuery

The URL does not include a path/query.

Implementations

impl Debug for UrlError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for UrlError

fn fmt(self: &Self, __formatter: &mut Formatter<'_>) -> Result

impl Eq for UrlError

impl Error for UrlError

impl Freeze for UrlError

impl PartialEq for UrlError

fn eq(self: &Self, other: &UrlError) -> bool

impl RefUnwindSafe for UrlError

impl Send for UrlError

impl StructuralPartialEq for UrlError

impl Sync for UrlError

impl Unpin for UrlError

impl UnsafeUnpin for UrlError

impl UnwindSafe for UrlError

impl<T> Any for UrlError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for UrlError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for UrlError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for UrlError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for UrlError

impl<T> ToString for UrlError

fn to_string(self: &Self) -> String

impl<T, U> Into for UrlError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for UrlError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for UrlError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<V, T> VZip for UrlError

fn vzip(self: Self) -> V