Enum Role

enum Role

Indicates a Client or Server role of the websocket

Variants

Server

This socket is a server

Client

This socket is a client

Implementations

impl Clone for Role

fn clone(self: &Self) -> Role

impl Copy for Role

impl Debug for Role

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Role

impl Freeze for Role

impl PartialEq for Role

fn eq(self: &Self, other: &Role) -> bool

impl RefUnwindSafe for Role

impl Send for Role

impl StructuralPartialEq for Role

impl Sync for Role

impl Unpin for Role

impl UnsafeUnpin for Role

impl UnwindSafe for Role

impl<T> Any for Role

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Role

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Role

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Role

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Role

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for Role

impl<T> ToOwned for Role

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Role

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Role

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Role

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<V, T> VZip for Role

fn vzip(self: Self) -> V